{
  config,
  lib,
  self,
  pkgs,
  ...
}:

{
  imports = [
    self.inputs.disko.nixosModules.disko
    ./hardware-configuration.nix
    ./disko-config.nix
    ../desktop.nix
  ];

  nixpkgs = {
    hostPlatform = "x86_64-linux";
    config = {
      allowUnfree = true;
      nvidia.acceptLicense = true;
    };
  };

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  networking.hostId = "cf791898";

  # nvidia 470 driver doesn't work with Wayland
  services = {
    xserver = {
      displayManager.gdm.wayland = lib.mkForce false;
      videoDrivers = [ "nvidia" ];
    };
    displayManager = {
      defaultSession = if config.modules.system.desktop.kde.enable then "plasmax11" else "gnome-xorg";
      sddm.wayland.enable = lib.mkForce false;
    };
  };

  # Workaround for label rendering bug in GTK4 with nvidia 470 driver
  environment.sessionVariables.GSK_RENDERER = "gl";

  environment.systemPackages = [
    pkgs.moonlight-qt
  ];

  modules = {
    programs = {
      dev = {
        node.enable = true;
      };
      firefox.enable = true;
      git.enable = true;
      gpg.enable = true;
      neovim.enable = true;
      pass.enable = true;
      recording = {
        audio.enable = true;
      };
    };
    shell = {
      zsh.enable = true;
    };
  };

  system.stateVersion = "22.11";
}
